/* Ergo, version 3.8, a program for linear scaling electronic structure
 * calculations.
 * Copyright (C) 2019 Elias Rudberg, Emanuel H. Rubensson, Pawel Salek,
 * and Anastasia Kruchinina.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Primary academic reference:
 * Ergo: An open-source program for linear-scaling electronic structure
 * calculations,
 * Elias Rudberg, Emanuel H. Rubensson, Pawel Salek, and Anastasia
 * Kruchinina,
 * SoftwareX 7, 107 (2018),
 * <http://dx.doi.org/10.1016/j.softx.2018.03.005>
 * 
 * For further information about Ergo, see <http://www.ergoscf.org>.
 */

/** @file hermite_conversion_explicit.h

    @brief Code for explicitly computing the matrix for conversion
    between integrals computed for Hermite Gaussians and Cartesian
    Gaussians, for given nmax and exponent values.

    @author: Elias Rudberg <em>responsible</em>
*/

#ifndef HERMITE_CONVERSION_EXPLICIT_HEADER
#define HERMITE_CONVERSION_EXPLICIT_HEADER

#include "realtype.h"
#include "monomial_info.h"

int get_hermite_conversion_matrix(const monomial_info_struct* monomial_info,
				  int nmax,
				  int inverseFlag,
				  ergo_real exponent,
				  ergo_real* result);


#endif
